/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_ADV_CONSTANTS_H_
#define _GB2_ADV_CONSTANTS_H_

namespace GB2 {

#define ADV_MENU_ANALYSE                "ADV_MENU_ANALYSE"
#define ADV_MENU_COPY                   "ADV_MENU_COPY"
#define ADV_MENU_SELECT                 "ADV_MENU_SELECT"
#define ADV_MENU_ADD                    "ADV_MENU_ADD"
#define ADV_MENU_REMOVE                 "ADV_MENU_REMOVE"
#define ADV_MENU_ZOOM                   "ADV_MENU_ZOOM"
#define ADV_MENU_EXPORT                 "ADV_MENU_EXPORT"
#define ADV_GOTO_ACTION                 "ADV_GOTO_ACTION"
#define ADV_MENU_SECTION1_SEP           "ADV_MENU_SEC1_SEP"
#define ADV_MENU_SECTION2_SEP           "ADV_MENU_SEC2_SEP"
#define ADV_MENU_EDIT                   "ADV_MENU_EDIT"

#define ANNOTATED_DNA_VIEW_FACTORY_ID   "AnnotatedDNAView"

} //namespace

#endif

